__author__ = 'michel'
# -*- coding: utf-8 -*-

import datetime, os, urllib, sys
import pprint



#from modules.web import db

from sqlalchemy import Boolean, Column, Date, DateTime, Float, Integer, String, Text, Time, ForeignKey
from libraries.database.database import db


class Model:
    def store(self, commit=False):
        db.session.add(self)
        if commit:
            self.commit()

    def commit(self):
        db.session.commit()



# ------------------------------------------------------------------------------------------ #
class TimeSlotModel(Model):
    def get_length(self):
        sec1 = int(datetime.datetime.strptime(self.start[0:16].replace(" ", "T"), "%Y-%m-%dT%H:%M").strftime("%s"))
        sec2 = int(datetime.datetime.strptime(self.end[0:16].replace(" ", "T"), "%Y-%m-%dT%H:%M").strftime("%s"))
        len = sec2 - sec1
        return len

    def pretty_print(self):
        return pprint.pprint(self)

class TimeSlotEntryModel(Model):
    # ------------------------------------------------------------------------------------------ #
    @staticmethod
    def upcoming(datefrom=datetime.datetime.now()):
        upcomingtracks = TimeSlotEntry.query.filter(TimeSlotEntry.start > datefrom).all()
        return upcomingtracks

    # ------------------------------------------------------------------------------------------ #
    @staticmethod
    def select_all():
        return TimeSlotEntry.query.filter().all()

    def __str__(self):
        return "TimeSlotEntry starts @ "+TimeSlotEntry.entry_start+" and ends @ "+TimeSlotEntry.entry_end+" and plays "+TimeSlotEntry.source

# ------------------------------------------------------------------------------------------ #
class TimeSlot(db.Model, TimeSlotModel):
    """
    One specific TimeSlot for a show
    """
    __tablename__ = 'timeslot'
    timeslot_id = Column(Integer, primary_key=True)
    show_id = Column(Integer)

    timeslot_start = Column(DateTime, nullable=False)
    timeslot_end = Column(DateTime, nullable=False)
    show_name = Column(String(255))
    show_hosts = Column(String(255))

    is_repetition = Column(Boolean())

    fallback_playlist = Column(String(255))
    fallback_pool = Column(String(255))
    station_fallback_pool = Column(String(255))

#    entry_start = Column(DateTime, nullable=False)
#    entry_end = Column(DateTime, nullable=False)
#    source = Column(String(255))

    def print(self):
        return "TimeSlot starts @ "+self.timeslot_start+" and ends @ "+self.timeslot_end+" and plays "+self.source


class TimeSlotEntry(db.Model, TimeSlotEntryModel):
    """
    One show can have multiple entries
    """
    #entry_id = Column(Integer, primary_key=True, autoincrement=True)
    __tablename__ = 'timeslotentry'
    timeslot_id = Column(Integer, ForeignKey("timeslot.timeslot_id"))
    entry_start = Column(DateTime, primary_key=True, nullable=False)
    entry_end = Column(DateTime, primary_key=True, nullable=False)
    source = Column(String(255))

#class Trackservice(db.Model, Model):
#    """
#    Trackservice and Logging
#    """
#    __tablename__ = 'trackservice'
#    id = Column(Integer, primary_key=True)
#    show_id = Column(Integer, ForeignKey("timeslot.id"))


def recreateDB():
    print("Recreating Database...")
    db.drop_all()
    print("all dropped. creating...")
    db.create_all()
    print("all created. commiting...")
    db.session.commit()
    print("Database recreated!")
    sys.exit(0)

#recreateDB()
